@@ -19,6 +19,7 @@ from calculate.lib.datavars import VariableError, DataVarsError
 from calculate.core.server.func import WsdlBase
 from calculate.desktop.desktop import DesktopError
 from client import ClientError
+from calculate.lib.utils.samba import SambaError
 from utils.cl_client import ClClientAction
 from utils.cl_passwd import ClPasswdAction
 from utils.cl_client_sync import (ClClientSyncLoginAction,
@@ -61,6 +62,7 @@ class Wsdl(WsdlBase):
             # объект переменных
             'datavars': "client",
             'native_error': (VariableError, DataVarsError,
+                             SambaError,
                              ClientError, DesktopError),
             # значения по умолчанию для переменных этого метода
             'setvars': {'cl_action!': 'domain',
@@ -105,6 +107,7 @@ class Wsdl(WsdlBase):
             # объект переменных
             'datavars': "client",
             'native_error': (VariableError, DataVarsError,
+                             SambaError,
                              ClientError, DesktopError),
             # значения по умолчанию для переменных этого метода
             'setvars': {'cl_action!': 'login'},
@@ -139,6 +142,7 @@ class Wsdl(WsdlBase):
             # объект переменных
             'datavars': "client",
             'native_error': (VariableError, DataVarsError,
+                             SambaError,
                              ClientError, DesktopError),
             # значения по умолчанию для переменных этого метода
             'setvars': {'cl_action!': 'logout'},
@@ -175,6 +179,7 @@ class Wsdl(WsdlBase):
             # объект переменных
             'datavars': "client",
             'native_error': (VariableError, DataVarsError,
+                             SambaError,
                              ClientError, DesktopError),
             # значения по умолчанию для переменных этого метода
             'setvars': {'cl_action!': 'passwd'},
